@@ -1,4 +1,4 @@
-## Copyright (C) 2015 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2015-2020 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -43,12 +43,26 @@ function varargout = netcellfun_worker (in_arrays, conns, func, varargin)
 
   nout = nargout ();
 
-   ## options are similar to for parcellfun/pararrayfun
+  ## options are similar to for parcellfun/pararrayfun
   [nargs, uniform_output, error_handler, verbose_level, ...
    ~, cumfunc, vectorized, chunk_size] = parcellfun_opts (fname, varargin);
   accumulate = ifelse (isempty (cumfunc), false, true);
   args = varargin(1:nargs);
 
+  if (nargs > 1)
+    [err, args{:}] = common_size (args{:});
+    if (err)
+      error ("%s: arguments size must match", fname);
+    endif
+  endif
+
+  argdims = size (args{1});
+  args_are_columns = iscolumn (args{1});
+  if (! args_are_columns)
+    args = cellfun (@ (x) x(:), args, "UniformOutput", false);
+  endif
+      
+
   ## configured or default number of processes at each machine
   rnproc = ifelse ([info.nlocaljobs] == 0, [info.nproc], [info.nlocaljobs]);
 
@@ -109,7 +123,6 @@ function varargout = netcellfun_worker (in_arrays, conns, func, varargin)
             (rnproc(id), func, varargs{:}, \
              'ChunksPerProc', 1, \
              'UniformOutput', false, \
-             'VerboseLevel', 0, \
              'Vectorized', vectorized, \
              'CumFunc', cumfunc, \
              'ErrorHandler', eh);", ...
@@ -129,7 +142,6 @@ function varargout = netcellfun_worker (in_arrays, conns, func, varargin)
             (rnproc(id), func, varargs{:}, \
              'ChunksPerProc', 1, \
              'UniformOutput', false, \
-             'VerboseLevel', 0, \
              'Vectorized', vectorized, \
              'CumFunc', cumfunc, \
              'ErrorHandler', \
@@ -253,4 +265,9 @@ function varargout = netcellfun_worker (in_arrays, conns, func, varargin)
 
   varargout = mat2cell (varargout, rows (varargout), ones (1, nout));
 
+  if (! (accumulate || args_are_columns))
+    varargout = cellfun (@ (x) reshape (x, argdims), varargout,
+                         "UniformOutput", false);
+  endif
+
 endfunction
