@@ -69,7 +69,8 @@ int minimal_read_header (std::istream& is, bool& swap,
 }
 
 int minimal_read_data (std::istream& is, octave_value& val,
-                       bool swap, OCTAVE__MACH_INFO::float_format flt_fmt)
+                       bool swap,
+                       OCTAVE__MACH_INFO::float_format flt_fmt)                 
 {
   int32_t len;
   if (! is.read (reinterpret_cast<char *> (&len), 4))
