@@ -17,6 +17,10 @@ this program; if not, see <http://www.gnu.org/licenses/>.
 
 */
 
+#ifndef __OCT_PARALLEL_LOAD_SAVE__
+
+#define __OCT_PARALLEL_LOAD_SAVE__
+
 #include <octave/oct.h>
 
 #include <octave/load-save.h>
@@ -27,8 +31,12 @@ int minimal_read_header (std::istream& is, bool& swap,
                          OCTAVE__MACH_INFO::float_format& flt_fmt);
 
 int minimal_read_data (std::istream& is, octave_value& val,
-                       bool swap, OCTAVE__MACH_INFO::float_format flt_fmt);
+                       bool swap = false,
+                       OCTAVE__MACH_INFO::float_format flt_fmt
+                       = OCTAVE__MACH_INFO::native_float_format ());
 
 void minimal_write_header (std::ostream& os);
 
 int minimal_write_data (std::ostream& os, octave_value& val);
+
+#endif // __OCT_PARALLEL_LOAD_SAVE__
