@@ -293,7 +293,7 @@ void check_options (p_cmdline_options &opts, int &oct_fd)
                 << "Copyright (C) 2002 Hayato Fujiwara." << std::endl
                 << "Copyright (C) 2010-2019 Olaf Till." << std::endl
                 << "This is free software; see the source code for copying conditions." << std::endl
-                << "There is ABSOLUTLY NO WARRANTY; not even for MERCHANTABILITY or" << std::endl 
+                << "There is ABSOLUTELY NO WARRANTY; not even for MERCHANTABILITY or" << std::endl 
                 << "FITNESS FOR A PARTICULAR PURPOSE." << std::endl
                 << std::endl
                 << "Usage:" << std::endl
