@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2019, 2020 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2019, 2023 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -63,6 +63,64 @@ namespace octave_parallel
 
     is = new std::istream (inbuf);
 
+#if defined CAN_GET_OCTAVE_CMDLINE_OPTIONS
+
+    int n_additional_args = 0;
+
+    bool no_init_file = false;
+
+    bool no_site_file = false;
+
+    if (! (octave::interpreter::the_interpreter ()
+           -> get_app_context () -> options ().read_init_files ())) {
+
+      n_additional_args += 1;
+
+      no_init_file = true;
+    }
+
+    if (! (octave::interpreter::the_interpreter ()
+           -> get_app_context () -> options ().read_site_files ())) {
+
+      n_additional_args += 1;
+
+      no_site_file = true;
+    }
+
+    // Some compilers with C++11 standard may have problems with
+    // variable length C arrays, so don't use them.
+    cstr_arr_guard args_guard (4 + n_additional_args);
+    char **args = args_guard.get_cstr_arr ();
+
+    copy_to_non_const arg_binary (octb.c_str ());
+    args[0] = arg_binary.get_str ();
+
+    copy_to_non_const arg_no_init_file_option ("--no-init-file");
+    if (no_init_file) {
+      args[1] = arg_no_init_file_option.get_str ();
+    }
+
+    copy_to_non_const arg_no_site_file_option ("--no-site-file");
+    if (no_site_file) {
+      args[n_additional_args] = arg_no_site_file_option.get_str ();
+    }
+
+    copy_to_non_const arg_eval_option ("--eval");
+    args[1 + n_additional_args] = arg_eval_option.get_str ();
+
+    std::stringstream eval_arg;
+    eval_arg << "pkg load parallel; __rfeval_slave__("
+             << (uint64_t)pps.get_out_read_handle () << ", "
+             << (uint64_t)pps.get_in_write_handle ()
+             << ")";
+    std::string eval_arg_str (eval_arg.str ());
+    copy_to_non_const arg_eval_command (eval_arg_str.c_str ());
+    args[2 + n_additional_args] = arg_eval_command.get_str ();
+
+    args[3 + n_additional_args] = NULL;
+
+#else
+
     char *args [4];
     copy_to_non_const arg_binary (octb.c_str ());
     args[0] = arg_binary.get_str ();
@@ -78,6 +136,8 @@ namespace octave_parallel
     args[2] = arg_eval_command.get_str ();
     args[3] = NULL;
 
+#endif
+
 #if defined _WIN32 && ! defined __CYGWIN__
 
     char *command = make_command_string (args[0], args);
