@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2019, 2020 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2019, 2023 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -274,6 +274,33 @@ namespace octave_parallel
     control *sched;
   };
 
+  class
+  cstr_arr_guard
+  {
+  public:
+
+    cstr_arr_guard (int n)
+    {
+      cstr_arr = new char* [n];
+    }
+
+    char **get_cstr_arr (void)
+    {
+      return cstr_arr;
+    }
+
+    ~cstr_arr_guard (void)
+    {
+      if (cstr_arr)
+        delete[] cstr_arr;
+    }
+
+  private:
+
+    char **cstr_arr;
+  };
+    
+
 } // namespace octave_parallel
 
 // For fexecve, we need to copy some const char* to non-const. Since
