@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2015-2018 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2015-2019 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,10 +21,23 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 #define BUFLEN 2048
 
+volatile sig_atomic_t octave_parallel_interrupted = 0;
+
+bool octave_parallel_assert_maybe_inthandler (void)
+{
+  static octave_parallel_maybe_inthandler maybe_inthandler;
+
+  return maybe_inthandler.good ();
+}
+
+void octave_parallel_inthandler (int signal)
+{
+  octave_parallel_interrupted = 1;
+}
+
 octave_parallel_socket_streambuf::
 octave_parallel_socket_streambuf (int sid, bool server,
                                   encryption_type encrtype)
-  : undefined_connection_state (false)
 {
   fid = sid;
 
@@ -102,6 +115,19 @@ octave_parallel_socket_streambuf (int sid, bool server,
     }
 }
 
+std::streamsize octave_parallel_socket_streambuf::showmanyc (void)
+{
+  if (! good () || fid == -1)
+    return -1;
+
+  std::streamsize ret;
+
+  if ((ret = gnulib_pollin_1_noblock (fid)) < 0)
+    store_errno = -1;
+
+  return ret;
+}
+
 #ifdef HAVE_LIBGNUTLS
 
 // Username was given as argument to 'connect'. appasswd is optional.
@@ -111,7 +137,7 @@ octave_parallel_gnutls_srp_client_credentials (const char *user,
 : password (apasswd), pw_allocated (false)
 {
   if (! password)
-    password = getpass ("password: ");
+    password = gnulib_getpass ("password: ");
 
   if (! strlen (password))
     {
