@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2015-2020 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2015-2023 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -44,24 +44,6 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 #include <stdint.h>
 
-// We link against the gnulib num_processors() used by Octave. nproc.h
-// used by Octave is not accessible. If the interface changes, this
-// will stop working.
-extern "C" {
-enum nproc_query
-{
-  NPROC_ALL,                 /* total number of processors */
-  NPROC_CURRENT,             /* processors available to the current process */
-  NPROC_CURRENT_OVERRIDABLE  /* likewise, but overridable through the
-                                OMP_NUM_THREADS environment variable */
-};
-
-/* Return the total number of processors.  The result is guaranteed to
-   be at least 1.  */
-extern unsigned long int num_processors (enum nproc_query query);
-}
-
-
 // Octave includes
 
 #include <octave/oct.h>
@@ -89,6 +71,16 @@ extern unsigned long int num_processors (enum nproc_query query);
 #include "sensitive-data.h"
 #endif
 
+// This gnulib file currently doesn't seem dangerous for C++, it just
+// defines an enum and the prototype of num_processors(...), which
+// isn't a system function but specific to gnulib. Note that older
+// versions of liboctave used to export the symbol of it's
+// gnulib-provided num_processors(...) for linking, whereas newer
+// versions don't do this and so our packages gnulib has to provide
+// this function; FIXME: prevent linking against (older) liboctave's
+// num_processors(...)?
+#include "gl/nproc.h"
+
 #include "gnulib-wrappers.h"
 
 #include "p-pipes.h"
